DarkHistory
===================

.. rubric:: Table of Sub-Modules

.. autosummary::
   :toctree: _autosummary
   
   main
   config

.. rubric:: Table of Packages

.. autosummary:: 
   :toctree: _autosummary

   darkhistory
